@@ -17,22 +17,51 @@ from departments.forms.forms import (
 from departments.utils.error_response import Response
 
 
-def get_departments(organization_id: int) -> dict:
+def get_departments(organization_id: int, department_name: str = None) -> dict:
     """
     通过组织id获取全量部门
     :param organization_id:
+    :param department_name:部门名称, 默认为空
     :return:
     """
+    # 没有搜索的情况, 直接获取全部
+    if not department_name:
+        instance = Department.objects.filter(
+            organization_id=organization_id,
+            path__isnull=True,
+            is_deleted=False
+        )
+        items = list()
 
-    instance = Department.objects.filter(
-        organization_id=organization_id,
-        path__isnull=True,
-        is_deleted=False
-    )
-    items = list()
+        for i in instance:
+            items.append(i.department_tree())
 
-    for i in instance:
-        items.append(i.department_tree())
+    # 有搜索的情况
+    else:
+        # 查询到包含搜索关键字的部门
+        departments = Department.objects.filter(
+            organization_id=organization_id,
+            name__contains=department_name,
+            is_deleted=False
+        )
+        items = list()
+        # 循环每一个部门
+        for instance in departments:
+            lst = list()
+            # 如果有父级的话, 查询到每一个父级部门的内容append到返回列表中
+            if instance.path:
+                for i in instance.path:
+                    dic = {}
+                    obj = Department.objects.filter(pk=i).only("name").first()
+                    dic["id"] = obj.id
+                    dic["name"] = obj.name
+                    lst.append(dic)
+            # 最后把部门本身的内容也append到返回列表中
+            lst.append({
+                "id": instance.id,
+                "name": instance.name
+            })
+            items.append(lst)
 
     return Response(data=items)
 
