@@ -35,10 +35,11 @@ if __name__ == '__main__':
 
 
     obj = DepartmentViewSet(1)
-    print(obj.list("sub", 2))
+    # print(obj.list("sub", 2))
     # print(obj.list("all"))
+    # print(obj.list("all", department_name="o"))
     # print(obj.create({"name": "前端", "parent_id": 4, "charger_id": None}))
-    # print(obj.retrieve(9))
+    print(obj.retrieve(3))
     # print(obj.update(2, {"name": "前端2", "parent_id": 4, "charger_id": None}))
     # print(obj.delete(9))
     # print(obj.move_show_order(9, "up"))
