@@ -29,15 +29,16 @@ class DepartmentViewSet(object):
     def retrieve(self, pk: int):
         return get_department_object(self.organization_id, pk)
 
-    def list(self, type_: str, department_id: int = None):
+    def list(self, type_: str, department_id: int = None, department_name: str = None):
         """
         获取部门列表.有两种方式. 1: 一次性获取; 2: 获取下一级部门.
         :param type_: 获取部门的方式, all: 一次性获取, sub: 获取下一级部门
         :param department_id: type_=sub时的部门id
+        :param department_name: 部门名称(搜索用)
         :return:
         """
         if type_ == "all":
-            return get_departments(self.organization_id)
+            return get_departments(self.organization_id, department_name)
         elif type_ == "sub":
             return get_sub_department(self.organization_id, department_id)
         else:
